import { ApiDOMStructuredError, ApiDOMErrorOptions } from '@swagger-api/apidom-error';
import { Element } from '@swagger-api/apidom-core';

declare class RelativeJsonPointerError extends ApiDOMStructuredError {
}

interface InvalidRelativeJsonPointerErrorOptions extends ApiDOMErrorOptions {
    readonly relativePointer: string;
}
declare class InvalidRelativeJsonPointerError extends RelativeJsonPointerError {
    readonly relativePointer: string;
    constructor(message?: string, structuredOptions?: InvalidRelativeJsonPointerErrorOptions);
}

interface EvaluationRelativeJsonPointerErrorOptions<T extends Element, U extends Element, V extends Element> extends ApiDOMErrorOptions {
    readonly relativePointer: string;
    readonly currentElement: T;
    readonly rootElement: U;
    readonly cursorElement?: V;
}
declare class EvaluationRelativeJsonPointerError<T extends Element, U extends Element, V extends Element> extends RelativeJsonPointerError {
    readonly relativePointer: string;
    readonly currentElement: T;
    readonly rootElement: U;
    readonly cursorElement?: V;
    constructor(message?: string, structuredOptions?: EvaluationRelativeJsonPointerErrorOptions<T, U, V>);
}

type RelativeJsonPointer = {
    readonly nonNegativeIntegerPrefix: number;
    readonly indexManipulation?: number;
    readonly jsonPointerTokens?: string[];
    readonly hashCharacter?: boolean;
};

interface CompilationRelativeJsonPointerErrorOptions extends ApiDOMErrorOptions {
    readonly relativePointer: RelativeJsonPointer;
}
declare class CompilationRelativeJsonPointerError extends RelativeJsonPointerError {
    readonly nonNegativeIntegerPrefix: number;
    readonly indexManipulation?: number;
    readonly jsonPointerTokens?: string[];
    readonly hashCharacter?: boolean;
    constructor(message?: string, structuredOptions?: CompilationRelativeJsonPointerErrorOptions);
}

declare const isRelativeJsonPointer: (value: any) => boolean;
declare const parse: (relativePointer: string) => RelativeJsonPointer;

declare const compile: (relativeJsonPointer: RelativeJsonPointer) => string;

declare const evaluate: <T extends Element, U extends Element>(relativePointer: string, currentElement: T, rootElement: U) => Element;

export { CompilationRelativeJsonPointerError, type CompilationRelativeJsonPointerErrorOptions, EvaluationRelativeJsonPointerError, type EvaluationRelativeJsonPointerErrorOptions, InvalidRelativeJsonPointerError, type InvalidRelativeJsonPointerErrorOptions, type RelativeJsonPointer, RelativeJsonPointerError, compile, evaluate, isRelativeJsonPointer, parse };
